searchData={"items":[{"type":"module","title":"Supex","doc":"Supex = SuperCollider + Elixir\n\nAn Elixir wrapper for the music live-coding language SuperCollider.\nSupex communicates with SuperCollider’s `sclang` tool, letting you generate and control sound directly from Elixir.\n\n- 🎧 Play basic oscillators with a clean, pipeable syntax\n- 🔤 Send raw SuperCollider code when needed\n- ⛔ Stop sounds by name\n\nBuilt for musicians, coders, and live performers who want to use Elixir for audio synthesis.\n\n👉 Requires `sclang` installed (`sudo apt install sclang` on Linux)","ref":"Supex.html"},{"type":"module","title":"Installation - Supex","doc":"The package can be installed by adding `supex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n[\n  {:supex, \"~> 0.1.0\"}\n]\nend\n```\n\n## 🔍 Learn SuperCollider basics\n\nhttps://doc.sccode.org/Tutorials/Getting-Started/00-Getting-Started-With-SC.html\n\n## ⚙️ Requirements:\nSuperCollider's `sclang` must be installed.\nExample (Linux): `sudo apt install sclang`\n\n## 🟢 Start the SuperCollider sclang server\n\n```elixir\niex> Supex.Sclang.start_link(:ok)\n```\n\n## 💡 Examples\n\n️▶ Play a sine oscillator at 269 Hz and name it \"y\"; then stop it:\n\n```elixir\niex> import Supex\niex> osc |> freq(269) |> name(\"y\") |> play\niex> osc |> name(\"y\") |> stop\n```\n\n▶ Modulate volume of a sine wave using another sine as LFO:\n\n```elixir\niex> import Supex\niex> osc |> mul(osc |> freq(2) |> mul(0.4) |> add(0.5) |> lfo) |> play\niex> osc |> stop\n```\n\n▶ Modulate a pulse wave's frequency and width:\n\n```elixir\niex> import Supex\niex> osc(:pulse) |> freq(\"SinOsc.kr(0.4).range(169, 269)\") |> width(\"SinOsc.kr(6.9).range(0.01, 0.8)\")|> mul(0.3) |> name(\"x\") |> play\niex> osc |> name(\"x\") |> stop\n```\n\n🔤 Send a raw SuperCollider expression:\n\n```elixir\niex> import Supex\niex> \"RLPF.ar(Pulse.ar([100, 250], 0.5, 0.1), XLine.kr(8000, 400, 5), 0.05)\" |> play\niex> osc |> name(\"z\") |> stop\n```\n\n## ⚠️ Disclaimer\n\nSuperCollider and Supex can produce loud, sudden sounds.\nUse volume control and a limiter to protect your ears.\nAvoid hearing damage.","ref":"Supex.html#module-installation"},{"type":"function","title":"Supex.add/2","doc":"Add the value to the signal.\nValues can be `0.1` or `1` for example.","ref":"Supex.html#add/2"},{"type":"function","title":"Supex.execute/1","doc":"Executes a raw SuperCollider's command on the `sclang` server.\n\nMust be a string.","ref":"Supex.html#execute/1"},{"type":"function","title":"Supex.freq/2","doc":"Tune the frequency of an oscillator.\n`freq` can be an integer or float.","ref":"Supex.html#freq/2"},{"type":"function","title":"Supex.lfo/1","doc":"Transforms a \"normal\" oscillator to a LFO to use it as a modulator.\n\nIt uses `kr` (control rate) instead of `ar`(audio rate),\ncf. https://doc.sccode.org/Tutorials/Getting-Started/05-Functions-and-Sound.html","ref":"Supex.html#lfo/1"},{"type":"function","title":"example - Supex.lfo/1","doc":"Modulate the volume of a sine wave with another sine wave as an LFO:\n\n  iex> import SC\n  iex> osc |> mul(osc |> freq(3) |> mul(0.5) |> add(0.5) |> lfo) |> play\n  iex> osc |> stop\n\n  or\n\n  iex> osc(:pulse) |> mul(osc|>freq(2)|>mul(0.4)|>add(0.5)|>lfo) |> freq(osc(:saw)|>freq(0.2)|>mul(100)|>add(100)|>lfo) |> play","ref":"Supex.html#lfo/1-example"},{"type":"function","title":"Supex.mul/2","doc":"Multiplication of the signal.\nChose values between `0.1` and `1` for not hurting your ears.","ref":"Supex.html#mul/2"},{"type":"function","title":"Supex.name/2","doc":"Adds a name for referencing.\ne.g. with a name the singnal can be stopped on the SuperCollider server.","ref":"Supex.html#name/2"},{"type":"function","title":"Supex.osc/1","doc":"Create a oscillator.\n`type` can be:\n\n  `:sin` (sinus wave)\n  `:saw` (saw wave)\n  `:pulse` (pulse wave, aka square wave)\n\nDefaults to `:sin`.","ref":"Supex.html#osc/1"},{"type":"function","title":"Supex.phase/2","doc":"The phase of a sinus wave.","ref":"Supex.html#phase/2"},{"type":"function","title":"Supex.play/1","doc":"Play the composed oscillator, or a raw SuperCollider's command (as a string).","ref":"Supex.html#play/1"},{"type":"function","title":"example - Supex.play/1","doc":"iex> import SC\n  iex> osc |> freq(269) |> name(\"y\") |> play","ref":"Supex.html#play/1-example"},{"type":"function","title":"Supex.stop/1","doc":"Stop playing a oscillator with a name.","ref":"Supex.html#stop/1"},{"type":"function","title":"example - Supex.stop/1","doc":"iex> import SC\n  iex> osc |> name(\"y\") |> stop","ref":"Supex.html#stop/1-example"},{"type":"function","title":"Supex.stop_playing/0","doc":"Stops all sound playing.","ref":"Supex.html#stop_playing/0"},{"type":"function","title":"Supex.synth/1","doc":"A synth definition.","ref":"Supex.html#synth/1"},{"type":"function","title":"Supex.width/2","doc":"The pulse width of an pulse wave oscillator.\n`width` should be a value between `0.01` and `0.99`.","ref":"Supex.html#width/2"},{"type":"module","title":"Supex.Example","doc":"Examples for using Supex.\n\nYou can play these examples with `Supex.play()`, e.g.\n\n   Supex.Example.pulse_wave_modulation_with_lfo() |> Supex.play()\n\nStop all playing sounds with `Supex.stop_playing()`.","ref":"Supex.Example.html"},{"type":"function","title":"Supex.Example.pulse_wave_modulation_with_lfo/0","doc":"","ref":"Supex.Example.html#pulse_wave_modulation_with_lfo/0"},{"type":"module","title":"Supex.Pan","doc":"Module for panning the sound.\n\nBy default SuperCollider uses only the left channel.\nWith panning you can ajust this for two speakers.\n\nSee SuperCollider's docs for `Pan2` https://doc.sccode.org/Classes/Pan2.html","ref":"Supex.Pan.html"},{"type":"function","title":"Supex.Pan.center/1","doc":"Pans the sound in the center.\n\nBy default SuperCollider uses only the left channel.\nSo with this you get the mono signal on both speakers.","ref":"Supex.Pan.html#center/1"},{"type":"module","title":"Supex.Sclang","doc":"Starts the port for SuperCollider's `sclang` and\nsends SuperCollider's commands to this `sclang` port.","ref":"Supex.Sclang.html"},{"type":"function","title":"Supex.Sclang.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Supex.Sclang.html#child_spec/1"},{"type":"function","title":"Supex.Sclang.close_port/0","doc":"","ref":"Supex.Sclang.html#close_port/0"},{"type":"function","title":"Supex.Sclang.execute/1","doc":"","ref":"Supex.Sclang.html#execute/1"},{"type":"function","title":"Supex.Sclang.start_link/1","doc":"Starts `sclang` via a port,\nand boots the SuperCollider server.","ref":"Supex.Sclang.html#start_link/1"},{"type":"function","title":"Supex.Sclang.stop_playing/0","doc":"","ref":"Supex.Sclang.html#stop_playing/0"},{"type":"module","title":"Supex.Sclang.ScPort","doc":"Port to the SuperCollider's command line tool `sclang`.","ref":"Supex.Sclang.ScPort.html"},{"type":"function","title":"Supex.Sclang.ScPort.close/1","doc":"","ref":"Supex.Sclang.ScPort.html#close/1"},{"type":"function","title":"Supex.Sclang.ScPort.open/0","doc":"Opens a port to SC's `sclang.`","ref":"Supex.Sclang.ScPort.html#open/0"},{"type":"function","title":"Supex.Sclang.ScPort.send_sc_command/2","doc":"Sends a SuperCollider's command to the `sclang` via the port.","ref":"Supex.Sclang.ScPort.html#send_sc_command/2"},{"type":"module","title":"Supex.Sclang.ScServer","doc":"Commands for a SC server, like booting or stop playing all sounds.","ref":"Supex.Sclang.ScServer.html"},{"type":"function","title":"Supex.Sclang.ScServer.boot/0","doc":"","ref":"Supex.Sclang.ScServer.html#boot/0"},{"type":"function","title":"Supex.Sclang.ScServer.booted/1","doc":"","ref":"Supex.Sclang.ScServer.html#booted/1"},{"type":"function","title":"Supex.Sclang.ScServer.stop_playing/0","doc":"","ref":"Supex.Sclang.ScServer.html#stop_playing/0"},{"type":"module","title":"Supex.Synth","doc":"","ref":"Supex.Synth.html"},{"type":"function","title":"Supex.Synth.define/1","doc":"","ref":"Supex.Synth.html#define/1"},{"type":"module","title":"Supex.Ugen","doc":"For composing Oscillators and other SuperCollider's UGens (UnitGnerators).","ref":"Supex.Ugen.html"},{"type":"module","title":"examples - Supex.Ugen","doc":"iex> import Supex.Ugen\niex> osc() |> freq(690) |> phase(6) |> mul(0.9) |> add(0.69) |> name(\"y\")\n%Supex.Ugen{add: 0.69, phase: 6, freq: 690, mul: 0.9, sc_command: \"SinOsc.ar(freq: 690, phase: 6, mul: 0.9, add: 0.69);\", sc_name: \"y\"}\n\niex> alias Supex.Ugen\niex> Ugen.osc(%Supex.Ugen{add: 0.69, phase: 6, freq: 690, mul: 0.9})\n%Supex.Ugen{add: 0.69, phase: 6, freq: 690, mul: 0.9, sc_command: \"SinOsc.ar(freq: 690, phase: 6, mul: 0.9, add: 0.69);\"}","ref":"Supex.Ugen.html#module-examples"},{"type":"function","title":"Supex.Ugen.add/2","doc":"","ref":"Supex.Ugen.html#add/2"},{"type":"function","title":"Supex.Ugen.freq/2","doc":"","ref":"Supex.Ugen.html#freq/2"},{"type":"function","title":"Supex.Ugen.lfo/1","doc":"Transforms a \"normal\" oscillator to a LFO.\n\nIt uses `kr` (control rate) instead of `ar`(audio rate),\ncf. https://doc.sccode.org/Tutorials/Getting-Started/05-Functions-and-Sound.html","ref":"Supex.Ugen.html#lfo/1"},{"type":"function","title":"Supex.Ugen.mul/2","doc":"","ref":"Supex.Ugen.html#mul/2"},{"type":"function","title":"Supex.Ugen.name/2","doc":"Name the oscillator.\nSuperCollider only excepts single chars, like \"y\", \"i\"...","ref":"Supex.Ugen.html#name/2"},{"type":"function","title":"Supex.Ugen.osc/1","doc":"","ref":"Supex.Ugen.html#osc/1"},{"type":"function","title":"Supex.Ugen.phase/2","doc":"","ref":"Supex.Ugen.html#phase/2"},{"type":"function","title":"Supex.Ugen.play/1","doc":"Adding play to the sc_command, and naming it for referencing.\n\nYou can pass a %Ugen{} struct or a SuperCollider's command.\n\nSupex and raw SuperCollider's command will by default refrenced with the variable \"x\".\nFor example, you can stop playing it with `osc() |> name(\"x\") |> stop()`","ref":"Supex.Ugen.html#play/1"},{"type":"function","title":"Supex.Ugen.stop/1","doc":"Stop sc_command with name reference.","ref":"Supex.Ugen.html#stop/1"},{"type":"function","title":"Supex.Ugen.width/2","doc":"","ref":"Supex.Ugen.html#width/2"},{"type":"extras","title":"Supex","doc":"# Supex\n\nSupex = SuperCollider + Elixir\n\nAn Elixir wrapper for the music live-coding language SuperCollider.\nSupex communicates with SuperCollider’s `sclang` tool, letting you generate and control sound directly from Elixir.\n\n- 🎧 Play basic oscillators with a clean, pipeable syntax\n- 🔤 Send raw SuperCollider code when needed\n- ⛔ Stop sounds by name\n\nBuilt for musicians, coders, and live performers who want to use Elixir for audio synthesis.\n\n👉 Requires `sclang` installed (`sudo apt install sclang` on Linux)","ref":"readme.html"},{"type":"extras","title":"Installation - Supex","doc":"The package can be installed by adding `supex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n[\n  {:supex, \"~> 0.1.0\"}\n]\nend\n```\n\n## 🔍 Learn SuperCollider basics\n\nhttps://doc.sccode.org/Tutorials/Getting-Started/00-Getting-Started-With-SC.html\n\n## ⚙️ Requirements:\nSuperCollider's `sclang` must be installed.\nExample (Linux): `sudo apt install sclang`\n\n## 🟢 Start the SuperCollider sclang server\n\n```elixir\niex> Supex.Sclang.start_link(:ok)\n```\n\n## 💡 Examples\n\n️▶ Play a sine oscillator at 269 Hz and name it \"y\"; then stop it:\n\n```elixir\niex> import Supex\niex> osc |> freq(269) |> name(\"y\") |> play\niex> osc |> name(\"y\") |> stop\n```\n\n▶ Modulate volume of a sine wave using another sine as LFO:\n\n```elixir\niex> import Supex\niex> osc |> mul(osc |> freq(2) |> mul(0.4) |> add(0.5) |> lfo) |> play\niex> osc |> stop\n```\n\n▶ Modulate a pulse wave's frequency and width:\n\n```elixir\niex> import Supex\niex> osc(:pulse) |> freq(\"SinOsc.kr(0.4).range(169, 269)\") |> width(\"SinOsc.kr(6.9).range(0.01, 0.8)\")|> mul(0.3) |> name(\"x\") |> play\niex> osc |> name(\"x\") |> stop\n```\n\n🔤 Send a raw SuperCollider expression:\n\n```elixir\niex> import Supex\niex> \"RLPF.ar(Pulse.ar([100, 250], 0.5, 0.1), XLine.kr(8000, 400, 5), 0.05)\" |> play\niex> osc |> name(\"z\") |> stop\n```\n\n## ⚠️ Disclaimer  \n\nSuperCollider and Supex can produce loud, sudden sounds.  \nUse volume control and a limiter to protect your ears.  \nAvoid hearing damage.","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}